@@ -20,15 +20,17 @@
 #define __PANEL_PRIVATE_H__
 
 #include <gtk/gtk.h>
-#ifdef GDK_WINDOWING_X11
+#ifdef ENABLE_X11
 #include <gdk/gdkx.h>
+#define WINDOWING_IS_X11() GDK_IS_X11_DISPLAY (gdk_display_get_default ())
 #else
-#define GDK_IS_X11_DISPLAY(display) FALSE
+#define WINDOWING_IS_X11() FALSE
 #endif
-#ifdef GDK_WINDOWING_WAYLAND
+#ifdef ENABLE_WAYLAND
 #include <gdk/gdkwayland.h>
+#define WINDOWING_IS_WAYLAND() GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ())
 #else
-#define GDK_IS_WAYLAND_DISPLAY(display) FALSE
+#define WINDOWING_IS_WAYLAND() FALSE
 #endif
 
 /* support macros for debugging (improved macro for better position indication) */
