@@ -35,7 +35,7 @@
 #define gtk_layer_is_supported() FALSE
 #endif
 
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #endif
@@ -126,7 +126,7 @@ struct _PanelApplication
   /* autohide count at application level */
   gint                autohide_block;
 
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
   guint               wait_for_wm_timeout_id;
 #endif
 
@@ -137,7 +137,7 @@ struct _PanelApplication
   guint               drop_index;
 };
 
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
 typedef struct
 {
   PanelApplication *application;
@@ -227,9 +227,9 @@ panel_application_init (PanelApplication *application)
   /* get a factory reference so it never unloads */
   application->factory = panel_module_factory_get ();
 
-#ifdef GDK_WINDOWING_WAYLAND
+#ifdef ENABLE_WAYLAND
   /* warn the user about restricted features on Wayland */
-  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+  if (WINDOWING_IS_WAYLAND ())
     {
       if (! gtk_layer_is_supported ())
         g_warning ("Wayland detected without layer-shell support (either because of your"
@@ -269,7 +269,7 @@ panel_application_finalize (GObject *object)
 
   panel_return_if_fail (application->dialogs == NULL);
 
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
   /* stop autostart timeout */
   if (application->wait_for_wm_timeout_id != 0)
     g_source_remove (application->wait_for_wm_timeout_id);
@@ -485,7 +485,7 @@ panel_application_load_real (PanelApplication *application)
 
 
 
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
 static gboolean
 panel_application_wait_for_window_manager (gpointer data)
 {
@@ -691,7 +691,7 @@ panel_application_plugin_provider_signal (XfcePanelPluginProvider       *provide
           /* widget dnd doesn't seem to work on Wayland without holding down a mouse button,
            * which leads to an unsolvable problem in GTK 3 because the plugin can't catch
            * the event before its child widgets (no "capture" phase as in GTK 4) */
-          if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+          if (WINDOWING_IS_WAYLAND ())
             {
               gint item;
               itembar = gtk_bin_get_child (GTK_BIN (window));
@@ -1227,13 +1227,13 @@ gboolean
 panel_application_load (PanelApplication  *application,
                         gboolean           disable_wm_check)
 {
-#ifdef HAVE_LIBX11
+#ifdef ENABLE_X11
   Display    *display;
   WaitForWM  *wfwm;
   guint       i;
   gchar     **atom_names;
 
-  if (!disable_wm_check && GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+  if (!disable_wm_check && WINDOWING_IS_X11 ())
     {
       display = XOpenDisplay (NULL);
       if (display == NULL)
@@ -1764,23 +1764,30 @@ panel_application_get_locked (PanelApplication *application)
 void
 panel_application_logout (void)
 {
-  XfceSMClient *sm_client;
-  GError       *error = NULL;
-  const gchar  *command = "xfce4-session-logout";
+  GError *error = NULL;
+  const gchar *command = "xfce4-session-logout";
 
+#ifdef ENABLE_X11
   /* first try to session client to logout else fallback and spawn xfce4-session-logout */
-  sm_client = xfce_sm_client_get ();
-  if (xfce_sm_client_is_connected (sm_client))
+  if (WINDOWING_IS_X11 ())
     {
-      xfce_sm_client_request_shutdown (sm_client, XFCE_SM_CLIENT_SHUTDOWN_HINT_ASK);
-
-      return;
+      XfceSMClient *sm_client = xfce_sm_client_get ();
+      if (xfce_sm_client_is_connected (sm_client))
+        {
+          xfce_sm_client_request_shutdown (sm_client, XFCE_SM_CLIENT_SHUTDOWN_HINT_ASK);
+          return;
+        }
     }
-  else if (g_getenv ("SESSION_MANAGER") == NULL)
+#endif
+
+  if (g_getenv ("SESSION_MANAGER") == NULL)
     {
-      if (xfce_dialog_confirm (NULL, "application-exit", _("Quit"),
-          _("You have started X without session manager. Clicking Quit will close the X server."),
-          _("Are you sure you want to quit the panel?")))
+      const gchar *text = NULL;
+      if (WINDOWING_IS_X11 ())
+        text = _("You have started X without session manager. Clicking Quit will close the X server.");
+
+      if (xfce_dialog_confirm (NULL, "application-exit", _("Quit"), text,
+                               _("Are you sure you want to quit the panel?")))
         command = "xfce4-panel --quit";
       else
         return;
