@@ -469,10 +469,13 @@ panel_dbus_service_get (void)
 void
 panel_dbus_service_exit_panel (gboolean restart)
 {
-  XfceSMClient *sm_client;
-
-  sm_client = xfce_sm_client_get ();
-  xfce_sm_client_set_restart_style (sm_client, XFCE_SM_CLIENT_RESTART_NORMAL);
+#ifdef ENABLE_X11
+  if (WINDOWING_IS_X11 ())
+    {
+      XfceSMClient *sm_client = xfce_sm_client_get ();
+      xfce_sm_client_set_restart_style (sm_client, XFCE_SM_CLIENT_RESTART_NORMAL);
+    }
+#endif
 
   dbus_exit_restart = !!restart;
 
