@@ -47,7 +47,6 @@ typedef enum _PanelModuleUnique  PanelModuleUnique;
 
 
 static void      panel_module_dispose          (GObject          *object);
-static void      panel_module_finalize         (GObject          *object);
 static gboolean  panel_module_load             (GTypeModule      *type_module);
 static void      panel_module_unload           (GTypeModule      *type_module);
 static void      panel_module_plugin_destroyed (gpointer          user_data,
@@ -112,7 +111,6 @@ panel_module_class_init (PanelModuleClass *klass)
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->dispose = panel_module_dispose;
-  gobject_class->finalize = panel_module_finalize;
 
   gtype_module_class = G_TYPE_MODULE_CLASS (klass);
   gtype_module_class->load = panel_module_load;
@@ -143,29 +141,26 @@ panel_module_init (PanelModule *module)
 
 static void
 panel_module_dispose (GObject *object)
-{
-  /* Do nothing to avoid problems with dispose in GTypeModule when
-   * types are registered.
-   *
-   * For us this is not a problem since the modules are released when
-   * everything is destroyed. So we really want that last unref before
-   * closing the application. */
-}
-
-
-
-static void
-panel_module_finalize (GObject *object)
 {
   PanelModule *module = PANEL_MODULE (object);
 
-  g_free (module->filename);
-  g_free (module->display_name);
-  g_free (module->comment);
-  g_free (module->icon_name);
-  g_free (module->api);
+  if (module->api != NULL)
+    {
+      g_free (module->filename);
+      g_free (module->display_name);
+      g_free (module->comment);
+      g_free (module->icon_name);
+      g_free (module->api);
+      module->api = NULL;
+      if (module->plugin_type != G_TYPE_NONE)
+        {
+          /* a module containing type implementations must exist forever */
+          g_object_ref (module);
+          return;
+        }
+    }
 
-  (*G_OBJECT_CLASS (panel_module_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (panel_module_parent_class)->dispose (object);
 }
 
 
@@ -362,7 +357,7 @@ panel_module_new_from_desktop_file (const gchar *filename,
           /* run mode of the module, by default everything runs in
            * the wrapper, unless defined otherwise or unsupported */
           if (forced_mode != PANEL_MODULE_RUN_MODE_INTERNAL
-              && (GDK_IS_X11_DISPLAY (gdk_display_get_default ()) || gtk_layer_is_supported ())
+              && (WINDOWING_IS_X11 () || gtk_layer_is_supported ())
               && (forced_mode == PANEL_MODULE_RUN_MODE_EXTERNAL
                   || !xfce_rc_read_bool_entry (rc, "X-XFCE-Internal", FALSE)))
             {
