@@ -33,7 +33,7 @@
 
 #include <gdk/gdk.h>
 #include <libxfce4util/libxfce4util.h>
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
 #include <panel/panel-plugin-external-wrapper-x11.h>
 #endif
 #ifdef HAVE_GTK_LAYER_SHELL
@@ -508,8 +508,8 @@ panel_plugin_external_wrapper_new (PanelModule  *module,
   panel_return_val_if_fail (PANEL_IS_MODULE (module), NULL);
   panel_return_val_if_fail (unique_id != -1, NULL);
 
-#ifdef HAVE_GTK_X11
-  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+#ifdef ENABLE_X11
+  if (WINDOWING_IS_X11 ())
     return g_object_new (PANEL_TYPE_PLUGIN_EXTERNAL_WRAPPER_X11,
                          "module", module,
                          "unique-id", unique_id,
