@@ -741,6 +741,7 @@ applications_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
                                        const GValue    *value)
 {
   ApplicationsMenuPlugin *plugin = APPLICATIONS_MENU_PLUGIN (panel_plugin);
+  GtkWidget *invisible;
 
   panel_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
@@ -749,14 +750,20 @@ applications_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
       || ! gtk_widget_get_visible (GTK_WIDGET (panel_plugin)))
     return FALSE;
 
+  invisible = gtk_invisible_new ();
+  gtk_widget_show (invisible);
+
   /* a menu is already shown, don't popup another one */
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (plugin->button))
-      || ! panel_utils_device_grab (plugin->button))
-    return TRUE;
+      || ! panel_utils_device_grab (invisible))
+    {
+      gtk_widget_destroy (invisible);
+      return TRUE;
+    }
 
   /*
-   * The menu will take over the grab when it is shown, and in the rare cases that it is not,
-   * this is not a big deal. This way we are sure that other invocations of the command by
+   * The menu will take over the grab when it is shown or it will be lost when destroying
+   * invisible below. This way we are sure that other invocations of the command by
    * keyboard shortcut will not interfere.
    */
   if (value != NULL
@@ -772,6 +779,8 @@ applications_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
       applications_menu_plugin_menu (plugin->button, NULL, plugin);
     }
 
+  gtk_widget_destroy (invisible);
+
   /* don't popup another menu */
   return TRUE;
 }
@@ -839,6 +848,8 @@ applications_menu_plugin_menu (GtkWidget              *button,
                                GdkEventButton         *event,
                                ApplicationsMenuPlugin *plugin)
 {
+  GdkEvent *free_event = NULL;
+
   panel_return_val_if_fail (APPLICATIONS_MENU_IS_PLUGIN (plugin), FALSE);
   panel_return_val_if_fail (button == NULL || plugin->button == button, FALSE);
 
@@ -855,9 +866,11 @@ applications_menu_plugin_menu (GtkWidget              *button,
    * gtk_menu_popup_at_pointer/rect can extract a location correctly from a GdkWindow */
   if (event == NULL)
     {
-      event = g_slice_new0 (GdkEventButton);
-      event->type = GDK_BUTTON_PRESS;
-      event->window = gdk_get_default_root_window ();
+      GdkSeat *seat = gdk_display_get_default_seat (gdk_display_get_default ());
+      free_event = gdk_event_new (GDK_BUTTON_PRESS);
+      free_event->button.window = g_object_ref (gdk_get_default_root_window ());
+      gdk_event_set_device (free_event, gdk_seat_get_pointer (seat));
+      event = (GdkEventButton *)free_event;
     }
 
   /* when cancelling a dnd only "selection-done" is emitted, whereas "deactivate" is more
@@ -867,8 +880,15 @@ applications_menu_plugin_menu (GtkWidget              *button,
   g_signal_connect (G_OBJECT (plugin->menu), "selection-done",
       G_CALLBACK (applications_menu_plugin_menu_popdown), plugin);
 
-  xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (plugin->menu),
-                                button, (GdkEvent *) event);
+  /* do not block panel autohide if popup-command at pointer */
+  if (button == NULL)
+    gtk_menu_popup_at_pointer (GTK_MENU (plugin->menu), (GdkEvent *) event);
+  else
+    xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (plugin->menu),
+                                  button, (GdkEvent *) event);
+
+  if (free_event != NULL)
+    gdk_event_free (free_event);
 
   return TRUE;
 }
