@@ -24,7 +24,6 @@
 #include <math.h>
 #endif
 
-#include <gtk/gtk.h>
 #include <cairo/cairo.h>
 #include <common/panel-private.h>
 
@@ -69,11 +68,6 @@ enum
   MODE_BINARY_TIME
 };
 
-struct _XfceClockBinaryClass
-{
-  GtkImageClass __parent__;
-};
-
 struct _XfceClockBinary
 {
   GtkImage  __parent__;
@@ -90,7 +84,7 @@ struct _XfceClockBinary
 
 
 
-XFCE_PANEL_DEFINE_TYPE (XfceClockBinary, xfce_clock_binary, GTK_TYPE_IMAGE)
+G_DEFINE_FINAL_TYPE (XfceClockBinary, xfce_clock_binary, GTK_TYPE_IMAGE)
 
 
 
