@@ -24,7 +24,6 @@
 #include <string.h>
 #endif
 
-#include <gtk/gtk.h>
 #include <common/panel-private.h>
 
 #include "clock.h"
@@ -67,11 +66,6 @@ enum
   PROP_ORIENTATION
 };
 
-struct _XfceClockFuzzyClass
-{
- GtkLabelClass __parent__;
-};
-
 struct _XfceClockFuzzy
 {
   GtkLabel __parent__;
@@ -169,7 +163,7 @@ static const gchar *i18n_hour_pm_names[] =
 
 
 
-XFCE_PANEL_DEFINE_TYPE (XfceClockFuzzy, xfce_clock_fuzzy, GTK_TYPE_LABEL)
+G_DEFINE_FINAL_TYPE (XfceClockFuzzy, xfce_clock_fuzzy, GTK_TYPE_LABEL)
 
 
 
