@@ -19,23 +19,14 @@
 #ifndef __PAGER_H__
 #define __PAGER_H__
 
-#include <gtk/gtk.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 G_BEGIN_DECLS
 
-typedef struct _PagerPluginClass PagerPluginClass;
-typedef struct _PagerPlugin      PagerPlugin;
+#define PAGER_TYPE_PLUGIN (pager_plugin_get_type ())
+G_DECLARE_FINAL_TYPE (PagerPlugin, pager_plugin, PAGER, PLUGIN, XfcePanelPlugin)
 
-#define XFCE_TYPE_PAGER_PLUGIN            (pager_plugin_get_type ())
-#define XFCE_PAGER_PLUGIN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFCE_TYPE_PAGER_PLUGIN, PagerPlugin))
-#define XFCE_PAGER_PLUGIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), XFCE_TYPE_PAGER_PLUGIN, PagerPluginClass))
-#define XFCE_IS_PAGER_PLUGIN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XFCE_TYPE_PAGER_PLUGIN))
-#define XFCE_IS_PAGER_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XFCE_TYPE_PAGER_PLUGIN))
-#define XFCE_PAGER_PLUGIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), XFCE_TYPE_PAGER_PLUGIN, PagerPluginClass))
-
-GType pager_plugin_get_type      (void) G_GNUC_CONST;
-
-void  pager_plugin_register_type (XfcePanelTypeModule *type_module);
+void pager_plugin_register_type (XfcePanelTypeModule *type_module);
 
 G_END_DECLS
 
