@@ -91,11 +91,6 @@ static void                  sn_backend_host_clear_items             (SnBackend
 
 
 
-struct _SnBackendClass
-{
-  GObjectClass         __parent__;
-};
-
 struct _SnBackend
 {
   GObject              __parent__;
@@ -110,7 +105,7 @@ struct _SnBackend
   GCancellable        *host_cancellable;
 };
 
-G_DEFINE_TYPE (SnBackend, sn_backend, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (SnBackend, sn_backend, G_TYPE_OBJECT)
 
 
 
@@ -168,7 +163,7 @@ sn_backend_class_init (SnBackendClass *klass)
                   G_SIGNAL_RUN_LAST,
                   0, NULL, NULL,
                   g_cclosure_marshal_VOID__OBJECT,
-                  G_TYPE_NONE, 1, XFCE_TYPE_SN_ITEM);
+                  G_TYPE_NONE, 1, SN_TYPE_ITEM);
 
   sn_backend_signals[ITEM_REMOVED] =
     g_signal_new (g_intern_static_string ("item-removed"),
@@ -176,7 +171,7 @@ sn_backend_class_init (SnBackendClass *klass)
                   G_SIGNAL_RUN_LAST,
                   0, NULL, NULL,
                   g_cclosure_marshal_VOID__OBJECT,
-                  G_TYPE_NONE, 1, XFCE_TYPE_SN_ITEM);
+                  G_TYPE_NONE, 1, SN_TYPE_ITEM);
 }
 
 
@@ -199,7 +194,7 @@ sn_backend_init (SnBackend *backend)
 static void
 sn_backend_finalize (GObject *object)
 {
-  SnBackend *backend = XFCE_SN_BACKEND (object);
+  SnBackend *backend = SN_BACKEND (object);
 
   g_object_unref (backend->host_cancellable);
 
@@ -228,7 +223,7 @@ sn_backend_finalize (GObject *object)
 SnBackend *
 sn_backend_new (void)
 {
-  return g_object_new (XFCE_TYPE_SN_BACKEND, NULL);
+  return g_object_new (SN_TYPE_BACKEND, NULL);
 }
 
 
@@ -236,7 +231,7 @@ sn_backend_new (void)
 void
 sn_backend_start (SnBackend *backend)
 {
-  g_return_if_fail (XFCE_IS_SN_BACKEND (backend));
+  g_return_if_fail (SN_IS_BACKEND (backend));
   g_return_if_fail (backend->watcher_bus_owner_id == 0);
   g_return_if_fail (backend->host_bus_watcher_id == 0);
 
@@ -733,7 +728,7 @@ sn_backend_host_add_item (SnBackend   *backend,
     }
   else
     {
-      item = g_object_new (XFCE_TYPE_SN_ITEM,
+      item = g_object_new (SN_TYPE_ITEM,
                            "bus-name", bus_name,
                            "object-path", object_path,
                            "key", service,
