@@ -78,11 +78,6 @@ enum
   PROP_HAS_HIDDEN
 };
 
-struct _SnBoxClass
-{
-  GtkContainerClass    __parent__;
-};
-
 struct _SnBox
 {
   GtkContainer         __parent__;
@@ -98,7 +93,7 @@ struct _SnBox
   gboolean             show_hidden;
 };
 
-G_DEFINE_TYPE (SnBox, sn_box, GTK_TYPE_CONTAINER)
+G_DEFINE_FINAL_TYPE (SnBox, sn_box, GTK_TYPE_CONTAINER)
 
 
 
@@ -152,7 +147,7 @@ sn_box_get_property(GObject *object,
                     GValue *value,
                     GParamSpec *pspec)
 {
-  SnBox *box = XFCE_SN_BOX(object);
+  SnBox *box = SN_BOX(object);
 
   switch (prop_id)
   {
@@ -171,7 +166,7 @@ sn_box_get_property(GObject *object,
 static void
 sn_box_finalize (GObject *object)
 {
-  SnBox *box = XFCE_SN_BOX (object);
+  SnBox *box = SN_BOX (object);
 
   g_hash_table_destroy (box->children);
 
@@ -183,7 +178,7 @@ sn_box_finalize (GObject *object)
 GtkWidget *
 sn_box_new (SnConfig *config)
 {
-  SnBox *box = g_object_new (XFCE_TYPE_SN_BOX, NULL);
+  SnBox *box = g_object_new (SN_TYPE_BOX, NULL);
 
   box->config = config;
 
@@ -201,7 +196,7 @@ static void
 sn_box_collect_known_items_callback (GtkWidget *widget,
                                      gpointer   user_data)
 {
-  SnButton   *button = XFCE_SN_BUTTON (widget);
+  SnButton   *button = SN_BUTTON (widget);
   GHashTable *table = user_data;
   gchar      *name;
 
@@ -229,8 +224,8 @@ sn_box_list_changed (SnBox    *box,
   GList    *known_items, *li, *li_int, *li_tmp;
   gint      n_hidden_children = 0, n_visible_children = 0;
 
-  g_return_if_fail (XFCE_IS_SN_BOX (box));
-  g_return_if_fail (XFCE_IS_SN_CONFIG (config));
+  g_return_if_fail (SN_IS_BOX (box));
+  g_return_if_fail (SN_IS_CONFIG (config));
 
   known_items = sn_config_get_known_items (box->config);
   for (li = known_items; li != NULL; li = li->next)
@@ -269,13 +264,13 @@ static void
 sn_box_add (GtkContainer *container,
             GtkWidget    *child)
 {
-  SnBox       *box = XFCE_SN_BOX (container);
-  SnButton    *button = XFCE_SN_BUTTON (child);
+  SnBox       *box = SN_BOX (container);
+  SnButton    *button = SN_BUTTON (child);
   GList       *li;
   const gchar *name;
 
-  g_return_if_fail (XFCE_IS_SN_BOX (box));
-  g_return_if_fail (XFCE_IS_SN_BUTTON (button));
+  g_return_if_fail (SN_IS_BOX (box));
+  g_return_if_fail (SN_IS_BUTTON (button));
   g_return_if_fail (gtk_widget_get_parent (GTK_WIDGET (child)) == NULL);
 
   name = sn_button_get_name (button);
@@ -294,8 +289,8 @@ static void
 sn_box_remove (GtkContainer *container,
                GtkWidget    *child)
 {
-  SnBox       *box = XFCE_SN_BOX (container);
-  SnButton    *button = XFCE_SN_BUTTON (child);
+  SnBox       *box = SN_BOX (container);
+  SnButton    *button = SN_BUTTON (child);
   GList       *li, *li_tmp;
   const gchar *name;
 
@@ -323,7 +318,7 @@ sn_box_forall (GtkContainer *container,
                GtkCallback   callback,
                gpointer      callback_data)
 {
-  SnBox    *box = XFCE_SN_BOX (container);
+  SnBox    *box = SN_BOX (container);
   SnButton *button;
   GList    *known_items, *li, *li_int, *li_tmp;
 
@@ -345,7 +340,7 @@ sn_box_forall (GtkContainer *container,
 static GType
 sn_box_child_type (GtkContainer *container)
 {
-  return XFCE_TYPE_SN_BUTTON;
+  return SN_TYPE_BUTTON;
 }
 
 
@@ -359,7 +354,7 @@ sn_box_measure_and_allocate (GtkWidget *widget,
                              gint       y0,
                              gboolean   horizontal)
 {
-  SnBox          *box = XFCE_SN_BOX (widget);
+  SnBox          *box = SN_BOX (widget);
   SnButton       *button;
   GList          *known_items, *li, *li_int, *li_tmp;
   gint            panel_size, config_nrows, icon_size, hx_size, hy_size, nrows;
@@ -495,7 +490,7 @@ sn_box_get_preferred_width (GtkWidget *widget,
                             gint      *minimum_width,
                             gint      *natural_width)
 {
-  SnBox *box = XFCE_SN_BOX (widget);
+  SnBox *box = SN_BOX (widget);
   gint   panel_size;
 
   if (sn_config_get_panel_orientation (box->config) == GTK_ORIENTATION_HORIZONTAL)
@@ -520,7 +515,7 @@ sn_box_get_preferred_height (GtkWidget *widget,
                              gint      *minimum_height,
                              gint      *natural_height)
 {
-  SnBox *box = XFCE_SN_BOX (widget);
+  SnBox *box = SN_BOX (widget);
   gint   panel_size;
 
   if (sn_config_get_panel_orientation (box->config) == GTK_ORIENTATION_VERTICAL)
@@ -544,7 +539,7 @@ static void
 sn_box_size_allocate (GtkWidget     *widget,
                       GtkAllocation *allocation)
 {
-  SnBox *box = XFCE_SN_BOX (widget);
+  SnBox *box = SN_BOX (widget);
 
   gtk_widget_set_allocation (widget, allocation);
 
@@ -563,7 +558,7 @@ sn_box_remove_item (SnBox  *box,
   SnButton *button;
   GList    *known_items, *li, *li_int, *li_tmp;
 
-  g_return_if_fail (XFCE_IS_SN_BOX (box));
+  g_return_if_fail (SN_IS_BOX (box));
 
   known_items = sn_config_get_known_items (box->config);
   for (li = known_items; li != NULL; li = li->next)
@@ -584,7 +579,7 @@ sn_box_remove_item (SnBox  *box,
 gboolean
 sn_box_has_hidden_items (SnBox *box)
 {
-  g_return_val_if_fail (XFCE_IS_SN_BOX (box), FALSE);
+  g_return_val_if_fail (SN_IS_BOX (box), FALSE);
   return box->n_hidden_children > 0;
 }
 
@@ -592,7 +587,7 @@ void
 sn_box_set_show_hidden (SnBox      *box,
                         gboolean    show_hidden)
 {
-  g_return_if_fail (XFCE_IS_SN_BOX (box));
+  g_return_if_fail (SN_IS_BOX (box));
 
   if (box->show_hidden != show_hidden)
     {
