@@ -35,7 +35,7 @@
 #include <common/panel-utils.h>
 #include <common/panel-debug.h>
 
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
 #include "systray.h"
 #include "systray-box.h"
 #include "systray-socket.h"
@@ -88,7 +88,7 @@ static void
 sn_plugin_init (SnPlugin *plugin)
 {
   /* Systray init */
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   plugin->manager = NULL;
   plugin->systray_box = NULL;
 #endif
@@ -119,7 +119,7 @@ sn_plugin_free (XfcePanelPlugin *panel_plugin)
   g_slist_free_full (plugin->names_ordered, g_free);
   g_hash_table_destroy (plugin->names_hidden);
 
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   if (G_LIKELY (plugin->manager != NULL))
     {
       systray_manager_unregister (plugin->manager);
@@ -157,7 +157,7 @@ sn_plugin_size_changed (XfcePanelPlugin *panel_plugin,
                       size,
                       xfce_panel_plugin_get_nrows (panel_plugin),
                       xfce_panel_plugin_get_icon_size (panel_plugin));
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   if (plugin->systray_box != NULL)
     systray_plugin_size_changed (panel_plugin,
                                  xfce_panel_plugin_get_size (panel_plugin));
@@ -181,7 +181,7 @@ sn_plugin_mode_changed (XfcePanelPlugin     *panel_plugin,
                 ? GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL;
 
   sn_config_set_orientation (plugin->config, panel_orientation, orientation);
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   if (plugin->systray_box != NULL)
     systray_plugin_orientation_changed (panel_plugin, panel_orientation);
 #endif
@@ -263,7 +263,7 @@ update_button_visibility (SnPlugin *plugin)
 }
 
 
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
 static void
 systray_has_hidden_cb (SystrayBox *box,
                        GParamSpec *pspec,
@@ -300,7 +300,7 @@ sn_plugin_button_toggled (GtkWidget *button,
 
   show_hidden = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
   sn_box_set_show_hidden (SN_BOX (plugin->sn_box), show_hidden);
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   if (plugin->systray_box != NULL)
     systray_box_set_show_hidden (SYSTRAY_BOX (plugin->systray_box), show_hidden);
 #endif
@@ -321,7 +321,7 @@ sn_plugin_construct (XfcePanelPlugin *panel_plugin)
 {
   SnPlugin *plugin = SN_PLUGIN (panel_plugin);
 
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   plugin->manager = NULL;
 #endif
   plugin->idle_startup = 0;
@@ -337,9 +337,9 @@ sn_plugin_construct (XfcePanelPlugin *panel_plugin)
   gtk_container_add (GTK_CONTAINER (plugin), plugin->box);
   gtk_widget_show (plugin->box);
 
-#ifdef HAVE_GTK_X11
+#ifdef ENABLE_X11
   /* Add systray box */
-  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+  if (WINDOWING_IS_X11 ())
     {
       plugin->systray_box = systray_box_new ();
       gtk_box_pack_start (GTK_BOX (plugin->box), plugin->systray_box, TRUE, TRUE, 0);
