@@ -39,11 +39,6 @@
 
 
 
-struct _SystraySocketClass
-{
-  GtkSocketClass __parent__;
-};
-
 struct _SystraySocket
 {
   GtkSocket __parent__;
@@ -69,7 +64,7 @@ static gboolean systray_socket_draw          (GtkWidget      *widget,
 
 
 
-XFCE_PANEL_DEFINE_TYPE (SystraySocket, systray_socket, GTK_TYPE_SOCKET)
+G_DEFINE_FINAL_TYPE (SystraySocket, systray_socket, GTK_TYPE_SOCKET)
 
 
 
@@ -102,7 +97,7 @@ systray_socket_init (SystraySocket *socket)
 static void
 systray_socket_finalize (GObject *object)
 {
-  SystraySocket *socket = XFCE_SYSTRAY_SOCKET (object);
+  SystraySocket *socket = SYSTRAY_SOCKET (object);
 
   g_free (socket->name);
 
@@ -114,7 +109,7 @@ systray_socket_finalize (GObject *object)
 static void
 systray_socket_realize (GtkWidget *widget)
 {
-  SystraySocket *socket = XFCE_SYSTRAY_SOCKET (widget);
+  SystraySocket *socket = SYSTRAY_SOCKET (widget);
   GdkRGBA        transparent = { 0.0, 0.0, 0.0, 0.0 };
   GdkWindow     *window;
 
@@ -169,7 +164,7 @@ static void
 systray_socket_size_allocate (GtkWidget     *widget,
                               GtkAllocation *allocation)
 {
-  SystraySocket *socket = XFCE_SYSTRAY_SOCKET (widget);
+  SystraySocket *socket = SYSTRAY_SOCKET (widget);
   GtkAllocation  widget_allocation;
   gboolean       moved;
   gboolean       resized;
@@ -207,7 +202,7 @@ static gboolean
 systray_socket_draw (GtkWidget *widget,
                      cairo_t   *cr)
 {
-  SystraySocket *socket = XFCE_SYSTRAY_SOCKET (widget);
+  SystraySocket *socket = SYSTRAY_SOCKET (widget);
 
   if (socket->is_composited)
     {
@@ -260,7 +255,7 @@ systray_socket_new (GdkScreen       *screen,
     return NULL;
 
   /* create a new socket */
-  socket = g_object_new (XFCE_TYPE_SYSTRAY_SOCKET, NULL);
+  socket = g_object_new (SYSTRAY_TYPE_SOCKET, NULL);
   socket->window = window;
   socket->is_composited = FALSE;
   gtk_widget_set_visual (GTK_WIDGET (socket), visual);
@@ -289,7 +284,7 @@ systray_socket_force_redraw (SystraySocket *socket)
   GdkDisplay    *display;
   GtkAllocation  allocation;
 
-  panel_return_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket));
+  panel_return_if_fail (SYSTRAY_IS_SOCKET (socket));
 
   if (gtk_widget_get_mapped (widget) && socket->parent_relative_bg)
     {
@@ -323,7 +318,7 @@ systray_socket_force_redraw (SystraySocket *socket)
 gboolean
 systray_socket_is_composited (SystraySocket *socket)
 {
-  panel_return_val_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket), FALSE);
+  panel_return_val_if_fail (SYSTRAY_IS_SOCKET (socket), FALSE);
 
   return socket->is_composited;
 }
@@ -344,7 +339,7 @@ systray_socket_get_name_prop (SystraySocket *socket,
   gulong      bytes_after;
   gchar      *name = NULL;
 
-  panel_return_val_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket), NULL);
+  panel_return_val_if_fail (SYSTRAY_IS_SOCKET (socket), NULL);
   panel_return_val_if_fail (type_name != NULL && prop_name != NULL, NULL);
 
   display = gtk_widget_get_display (GTK_WIDGET (socket));
@@ -388,7 +383,7 @@ systray_socket_get_name_prop (SystraySocket *socket,
 const gchar *
 systray_socket_get_name (SystraySocket *socket)
 {
-  panel_return_val_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket), NULL);
+  panel_return_val_if_fail (SYSTRAY_IS_SOCKET (socket), NULL);
 
   if (G_LIKELY (socket->name != NULL))
     return socket->name;
@@ -407,7 +402,7 @@ systray_socket_get_name (SystraySocket *socket)
 Window *
 systray_socket_get_window (SystraySocket *socket)
 {
-  panel_return_val_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket), NULL);
+  panel_return_val_if_fail (SYSTRAY_IS_SOCKET (socket), NULL);
 
   return &socket->window;
 }
@@ -417,7 +412,7 @@ systray_socket_get_window (SystraySocket *socket)
 gboolean
 systray_socket_get_hidden (SystraySocket *socket)
 {
-  panel_return_val_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket), FALSE);
+  panel_return_val_if_fail (SYSTRAY_IS_SOCKET (socket), FALSE);
 
   return socket->hidden;
 }
@@ -428,7 +423,7 @@ void
 systray_socket_set_hidden (SystraySocket *socket,
                            gboolean       hidden)
 {
-  panel_return_if_fail (XFCE_IS_SYSTRAY_SOCKET (socket));
+  panel_return_if_fail (SYSTRAY_IS_SOCKET (socket));
 
   socket->hidden = hidden;
 }
