@@ -579,6 +579,7 @@ window_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
                                  const GValue    *value)
 {
   WindowMenuPlugin *plugin = WINDOW_MENU_PLUGIN (panel_plugin);
+  GtkWidget *invisible;
 
   panel_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
@@ -587,14 +588,20 @@ window_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
       || ! gtk_widget_get_visible (GTK_WIDGET (panel_plugin)))
     return FALSE;
 
+  invisible = gtk_invisible_new ();
+  gtk_widget_show (invisible);
+
   /* a menu is already shown, don't popup another one */
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (plugin->button))
-      || ! panel_utils_device_grab (plugin->button))
-    return TRUE;
+      || ! panel_utils_device_grab (invisible))
+    {
+      gtk_widget_destroy (invisible);
+      return TRUE;
+    }
 
   /*
-   * The menu will take over the grab when it is shown, and in the rare cases that it is not,
-   * this is not a big deal. This way we are sure that other invocations of the command by
+   * The menu will take over the grab when it is shown or it will be lost when destroying
+   * invisible below. This way we are sure that other invocations of the command by
    * keyboard shortcut will not interfere.
    */
   if (value != NULL
@@ -610,6 +617,8 @@ window_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (plugin->button), TRUE);
     }
 
+  gtk_widget_destroy (invisible);
+
   /* don't popup another menu */
   return TRUE;
 }
@@ -1400,8 +1409,8 @@ static void
 window_menu_plugin_menu (GtkWidget        *button,
                          WindowMenuPlugin *plugin)
 {
-  GtkWidget      *menu;
-  GdkEventButton *event = NULL;
+  GtkWidget *menu;
+  GdkEvent  *event = NULL;
 
   panel_return_if_fail (WINDOW_MENU_IS_PLUGIN (plugin));
   panel_return_if_fail (button == NULL || plugin->button == button);
@@ -1412,11 +1421,13 @@ window_menu_plugin_menu (GtkWidget        *button,
 
   /* Panel plugin remote events don't send actual GdkEvents, so construct a minimal one so that
    * gtk_menu_popup_at_pointer/rect can extract a location correctly from a GdkWindow */
-  if (gtk_get_current_event () == NULL)
+  event = gtk_get_current_event ();
+  if (event == NULL)
     {
-      event = g_slice_new0 (GdkEventButton);
-      event->type = GDK_BUTTON_PRESS;
-      event->window = gdk_get_default_root_window ();
+      GdkSeat *seat = gdk_display_get_default_seat (gdk_display_get_default ());
+      event = gdk_event_new (GDK_BUTTON_PRESS);
+      event->button.window = g_object_ref (gdk_get_default_root_window ());
+      gdk_event_set_device (event, gdk_seat_get_pointer (seat));
     }
 
   /* popup the menu */
@@ -1424,6 +1435,11 @@ window_menu_plugin_menu (GtkWidget        *button,
   g_signal_connect (G_OBJECT (menu), "deactivate",
       G_CALLBACK (window_menu_plugin_menu_deactivate), plugin);
 
-  xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (menu),
-                                button, (GdkEvent *) event);
+  /* do not block panel autohide if popup-command at pointer */
+  if (button == NULL)
+    gtk_menu_popup_at_pointer (GTK_MENU (menu), event);
+  else
+    xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (menu), button, event);
+
+  gdk_event_free (event);
 }
